@@ -3,12 +3,12 @@ set -e
 
 J2F_DIRLIST="/etc/json2file-go/dirlist"
 
-HOSTNAME="localhost"
-SUBJECT="/CN=$HOSTNAME/"
+HOST_NAME="localhost"
+SUBJECT="/CN=$HOST_NAME/"
 
 TLS_DIR="/etc/json2file-go/tls"
-CERTFILE="$TLS_DIR/${HOSTNAME}.crt"
-KEYFILE="$TLS_DIR/${HOSTNAME}.key"
+CERTFILE="$TLS_DIR/${HOST_NAME}.crt"
+KEYFILE="$TLS_DIR/${HOST_NAME}.key"
 
 mkcert() {
 	[ -d "$TLS_DIR" ] || mkdir "$TLS_DIR"
